async_rx_init

Function async_rx_init 

pub unsafe extern "C" fn async_rx_init(
    s: *mut async_rx_state_t,
    data_bits: c_int,
    parity: c_int,
    stop_bits: c_int,
    use_v14: bool,
    put_byte: span_put_byte_func_t,
    user_data: *mut c_void,
) -> *mut async_rx_state_t
Initialise an asynchronous data receiver context. \brief Initialise an asynchronous data receiver context. \param s The receiver context. \param data_bits The number of data bits. \param parity The type of parity. \param stop_bits The number of stop bits. \param use_v14 True if V.14 rate adaption processing should be used. \param put_byte The callback routine used to put the received data. \param user_data An opaque pointer. \return A pointer to the initialised context, or NULL if there was a problem.