lpc10_encode

Function lpc10_encode 

pub unsafe extern "C" fn lpc10_encode(
    s: *mut lpc10_encode_state_t,
    code: *mut u8,
    amp: *const i16,
    len: c_int,
) -> c_int
Encode a buffer of linear PCM data to LPC10e. \param s The LPC10e context. \param ima_data The LPC10e data produced. \param amp The audio sample buffer. \param len The number of samples in the buffer. This must be a multiple of 180, as this is the number of samples on a frame. \return The number of bytes of LPC10e data produced.