queue_init

Function queue_init 

pub unsafe extern "C" fn queue_init(
    s: *mut queue_state_t,
    len: c_int,
    flags: c_int,
) -> *mut queue_state_t
Initialise a queue. \brief Initialise a queue. \param s The queue context. If is imperative that the context this points to is immediately followed by a buffer of the required size + 1 octet. \param len The length of the queue’s buffer. \param flags Flags controlling the operation of the queue. Valid flags are QUEUE_READ_ATOMIC and QUEUE_WRITE_ATOMIC. \return A pointer to the context if OK, else NULL.