t42_decode_set_comment_handler

Function t42_decode_set_comment_handler 

pub unsafe extern "C" fn t42_decode_set_comment_handler(
    s: *mut t42_decode_state_t,
    max_comment_len: u32,
    handler: t4_row_write_handler_t,
    user_data: *mut c_void,
) -> c_int
\brief Set the comment handler routine. \param s The T.42 context. \param max_comment_len The maximum length of comment to be passed to the handler. \param handler A callback routine to handle decoded comment. \param user_data An opaque pointer passed to handler. \return 0 for OK.