pub unsafe extern "C" fn t4_tx_get_tx_image_width_code(
s: *mut t4_tx_state_t,
) -> c_intExpand description
\brief Get the width code of the encoded data. \param s The T.4 context. \return the width code, for success, otherwise -1.
pub unsafe extern "C" fn t4_tx_get_tx_image_width_code(
s: *mut t4_tx_state_t,
) -> c_int\brief Get the width code of the encoded data. \param s The T.4 context. \return the width code, for success, otherwise -1.