pub unsafe extern "C" fn t85_encode_set_image_length(
s: *mut t85_encode_state_t,
image_length: u32,
) -> c_intExpand description
\brief Alter the length of a T.85 encoded image. The new length cannot be greater than the originally specified length. If the new length is less than the current length it will be silently adjusted to the current length. Therefore, adjust the length to 1 will make the currently encoded length the final length. \param s The T.85 context. \param image_length The new image length, in pixels. \return 0 if OK, or -1 if the request was not valid.