time_scale

Function time_scale 

pub unsafe extern "C" fn time_scale(
    s: *mut time_scale_state_t,
    out: *mut i16,
    in_: *mut i16,
    len: c_int,
) -> c_int
Time scale a chunk of audio samples. \brief Time scale a chunk of audio samples. \param s The time scale context. \param out The output audio sample buffer. This must be large enough to accept the longest possible result from processing the input data. See the algorithm documentation for how the longest possible result may be calculated. \param in The input audio sample buffer. \param len The number of input samples. \return The number of output samples.