time_scale_init

Function time_scale_init 

pub unsafe extern "C" fn time_scale_init(
    s: *mut time_scale_state_t,
    sample_rate: c_int,
    playout_rate: f32,
) -> *mut time_scale_state_t
Initialise a time scale context. This must be called before the first use of the context, to initialise its contents. \brief Initialise a time scale context. \param s The time scale context. \param sample_rate The sample rate of the signal. \param playout_rate The ratio between the output speed and the input speed. \return A pointer to the context, or NULL if there was a problem.