#[repr(C)]pub struct fsk_spec_t {
pub name: *const c_char,
pub freq_zero: c_int,
pub freq_one: c_int,
pub tx_level: c_int,
pub min_level: c_int,
pub baud_rate: c_int,
}Expand description
FSK modem specification. This defines the frequencies, signal levels and baud rate (== bit rate for simple FSK) for a single channel of an FSK modem.
Fields
name: *const c_charShort text name for the modem.
freq_zero: c_intThe frequency of the zero bit state, in Hz
freq_one: c_intThe frequency of the one bit state, in Hz
tx_level: c_intThe transmit power level, in dBm0
min_level: c_intThe minimum acceptable receive power level, in dBm0
baud_rate: c_intThe bit rate of the modem, in units of 1/100th bps