#[repr(C)]pub struct t30_stats_t {Show 23 fields
pub bit_rate: c_int,
pub error_correcting_mode: c_int,
pub pages_tx: c_int,
pub pages_rx: c_int,
pub pages_in_file: c_int,
pub image_type: c_int,
pub image_x_resolution: c_int,
pub image_y_resolution: c_int,
pub image_width: c_int,
pub image_length: c_int,
pub type_: c_int,
pub x_resolution: c_int,
pub y_resolution: c_int,
pub width: c_int,
pub length: c_int,
pub image_size: c_int,
pub compression: c_int,
pub bad_rows: c_int,
pub longest_bad_row_run: c_int,
pub error_correcting_mode_retries: c_int,
pub current_status: c_int,
pub rtp_events: c_int,
pub rtn_events: c_int,
}Fields
bit_rate: c_int\brief The current bit rate for image transfer.
error_correcting_mode: c_int\brief True if error correcting mode is used.
pages_tx: c_int\brief The number of pages sent so far.
pages_rx: c_int\brief The number of pages received so far.
pages_in_file: c_int\brief The number of pages in the file (<0 if not known).
image_type: c_int\brief The type of image of the most recent file page
image_x_resolution: c_int\brief The horizontal column-to-column resolution of the most recent file page, in pixels per metre
image_y_resolution: c_int\brief The vertical row-to-row resolution of the most recent file page, in pixels per metre
image_width: c_int\brief The number of horizontal pixels in the most recent file page.
image_length: c_int\brief The number of vertical pixels in the most recent file page.
type_: c_int\brief The type of image of the most recent exchanged page
x_resolution: c_int\brief The horizontal column-to-column resolution of the most recent exchanged page, in pixels per metre
y_resolution: c_int\brief The vertical row-to-row resolution of the most recent exchanged page, in pixels per metre
width: c_int\brief The number of horizontal pixels in the most recent exchanged page.
length: c_int\brief The number of vertical pixels in the most recent exchanged page.
image_size: c_int\brief The size of the image, in bytes
compression: c_int\brief The type of compression used between the FAX machines
bad_rows: c_int\brief The number of bad pixel rows in the most recent page.
longest_bad_row_run: c_int\brief The largest number of bad pixel rows in a block in the most recent page.
error_correcting_mode_retries: c_int\brief The number of HDLC frame retries, if error correcting mode is used.
current_status: c_int\brief Current status.
rtp_events: c_int\brief The number of RTP events in this call.
rtn_events: c_int\brief The number of RTN events in this call.