t4_stats_t

Struct t4_stats_t 

#[repr(C)]
pub struct t4_stats_t {
Show 16 fields pub pages_transferred: c_int, pub pages_in_file: c_int, pub bad_rows: c_int, pub longest_bad_row_run: c_int, pub image_type: c_int, pub image_x_resolution: c_int, pub image_y_resolution: c_int, pub image_width: c_int, pub image_length: c_int, pub type_: c_int, pub x_resolution: c_int, pub y_resolution: c_int, pub width: c_int, pub length: c_int, pub compression: c_int, pub line_image_size: c_int,
}
T.4 FAX compression/decompression statistics.

Fields

pages_transferred: c_int

\brief The number of pages transferred so far.

pages_in_file: c_int

\brief The number of pages in the file (<0 if unknown).

bad_rows: c_int

\brief The number of bad pixel rows in the most recent page.

longest_bad_row_run: c_int

\brief The largest number of bad pixel rows in a block in the most recent page.

image_type: c_int

\brief The type of image in the file page

image_x_resolution: c_int

\brief The horizontal resolution of the file page in pixels per metre

image_y_resolution: c_int

\brief The vertical resolution of the file page in pixels per metre

image_width: c_int

\brief The number of horizontal pixels in the file page.

image_length: c_int

\brief The number of vertical pixels in the file page.

type_: c_int

\brief The type of image in the exchanged page

x_resolution: c_int

\brief The horizontal resolution of the exchanged page in pixels per metre

y_resolution: c_int

\brief The vertical resolution of the exchanged page in pixels per metre

width: c_int

\brief The number of horizontal pixels in the exchanged page.

length: c_int

\brief The number of vertical pixels in the exchanged page.

compression: c_int

\brief The type of compression used between the FAX machines

line_image_size: c_int

\brief The size of the image on the line, in bytes