async_tx_state_t

Type Alias async_tx_state_t 

pub type async_tx_state_t = async_tx_state_s;
Asynchronous data transmit descriptor. This defines the state of a single working instance of a byte to asynchronous serial converter, for use in FSK modems.

Aliased Type

pub struct async_tx_state_t { /* private fields */ }