pub type bert_state_t = bert_state_s;Expand description
Bit error rate tester (BERT) descriptor. This defines the working state for a single instance of the BERT.
Aliased Type
pub struct bert_state_t { /* private fields */ }pub type bert_state_t = bert_state_s;Bit error rate tester (BERT) descriptor. This defines the working state for a single instance of the BERT.
pub struct bert_state_t { /* private fields */ }