pub type echo_can_state_t = echo_can_state_s;Expand description
G.168 echo canceller descriptor. This defines the working state for a line echo canceller.
Aliased Type
pub struct echo_can_state_t { /* private fields */ }pub type echo_can_state_t = echo_can_state_s;G.168 echo canceller descriptor. This defines the working state for a line echo canceller.
pub struct echo_can_state_t { /* private fields */ }