pub type logging_state_t = logging_state_s;Expand description
Logging descriptor. This defines the working state for a single instance of the logging facility for spandsp.
Aliased Type
pub struct logging_state_t { /* private fields */ }pub type logging_state_t = logging_state_s;Logging descriptor. This defines the working state for a single instance of the logging facility for spandsp.
pub struct logging_state_t { /* private fields */ }