pub type t30_set_handler_t = Option<unsafe extern "C" fn(user_data: *mut c_void, type_: c_int, bit_rate: c_int, short_train: c_int, use_hdlc: c_int)>;Expand description
T.30 set a receive or transmit type handler. \brief T.30 set a receive or transmit type handler. \param user_data An opaque pointer. \param type The modem, tone or silence to be sent or received. \param bit_rate The bit rate of the modem to be sent or received. \param short_train True if the short training sequence should be used (where one exists). \param use_hdlc False for bit stream, true for HDLC framing.
Aliased Type
pub enum t30_set_handler_t {
None,
Some(unsafe extern "C" fn(*mut c_void, i32, i32, i32, i32)),
}