#[repr(u32)]pub enum t30_err_e {
Show 62 variants
T30_ERR_OK = 0,
T30_ERR_CEDTONE = 1,
T30_ERR_T0_EXPIRED = 2,
T30_ERR_T1_EXPIRED = 3,
T30_ERR_T3_EXPIRED = 4,
T30_ERR_HDLC_CARRIER = 5,
T30_ERR_CANNOT_TRAIN = 6,
T30_ERR_OPER_INT_FAIL = 7,
T30_ERR_INCOMPATIBLE = 8,
T30_ERR_RX_INCAPABLE = 9,
T30_ERR_TX_INCAPABLE = 10,
T30_ERR_NORESSUPPORT = 11,
T30_ERR_NOSIZESUPPORT = 12,
T30_ERR_UNEXPECTED = 13,
T30_ERR_TX_BADDCS = 14,
T30_ERR_TX_BADPG = 15,
T30_ERR_TX_ECMPHD = 16,
T30_ERR_TX_GOTDCN = 17,
T30_ERR_TX_INVALRSP = 18,
T30_ERR_TX_NODIS = 19,
T30_ERR_TX_PHBDEAD = 20,
T30_ERR_TX_PHDDEAD = 21,
T30_ERR_TX_T5EXP = 22,
T30_ERR_RX_ECMPHD = 23,
T30_ERR_RX_GOTDCS = 24,
T30_ERR_RX_INVALCMD = 25,
T30_ERR_RX_NOCARRIER = 26,
T30_ERR_RX_NOEOL = 27,
T30_ERR_RX_NOFAX = 28,
T30_ERR_RX_T2EXPDCN = 29,
T30_ERR_RX_T2EXPD = 30,
T30_ERR_RX_T2EXPFAX = 31,
T30_ERR_RX_T2EXPMPS = 32,
T30_ERR_RX_T2EXPRR = 33,
T30_ERR_RX_T2EXP = 34,
T30_ERR_RX_DCNWHY = 35,
T30_ERR_RX_DCNDATA = 36,
T30_ERR_RX_DCNFAX = 37,
T30_ERR_RX_DCNPHD = 38,
T30_ERR_RX_DCNRRD = 39,
T30_ERR_RX_DCNNORTN = 40,
T30_ERR_FILEERROR = 41,
T30_ERR_NOPAGE = 42,
T30_ERR_BADTIFF = 43,
T30_ERR_BADPAGE = 44,
T30_ERR_BADTAG = 45,
T30_ERR_BADTIFFHDR = 46,
T30_ERR_NOMEM = 47,
T30_ERR_RETRYDCN = 48,
T30_ERR_CALLDROPPED = 49,
T30_ERR_NOPOLL = 50,
T30_ERR_IDENT_UNACCEPTABLE = 51,
T30_ERR_SUB_UNACCEPTABLE = 52,
T30_ERR_SEP_UNACCEPTABLE = 53,
T30_ERR_PSA_UNACCEPTABLE = 54,
T30_ERR_SID_UNACCEPTABLE = 55,
T30_ERR_PWD_UNACCEPTABLE = 56,
T30_ERR_TSA_UNACCEPTABLE = 57,
T30_ERR_IRA_UNACCEPTABLE = 58,
T30_ERR_CIA_UNACCEPTABLE = 59,
T30_ERR_ISP_UNACCEPTABLE = 60,
T30_ERR_CSA_UNACCEPTABLE = 61,
}Expand description
T.30 protocol completion codes, at phase E.
Variants
T30_ERR_OK = 0
T30_ERR_CEDTONE = 1
OK
T30_ERR_T0_EXPIRED = 2
The CED tone exceeded 5s
T30_ERR_T1_EXPIRED = 3
Timed out waiting for initial communication
T30_ERR_T3_EXPIRED = 4
Timed out waiting for the first message
T30_ERR_HDLC_CARRIER = 5
Timed out waiting for procedural interrupt
T30_ERR_CANNOT_TRAIN = 6
The HDLC carrier did not stop in a timely manner
T30_ERR_OPER_INT_FAIL = 7
Failed to train with any of the compatible modems
T30_ERR_INCOMPATIBLE = 8
Operator intervention failed
T30_ERR_RX_INCAPABLE = 9
Far end is not compatible
T30_ERR_TX_INCAPABLE = 10
Far end is not able to receive
T30_ERR_NORESSUPPORT = 11
Far end is not able to transmit
T30_ERR_NOSIZESUPPORT = 12
Far end cannot receive at the resolution of the image
T30_ERR_UNEXPECTED = 13
Far end cannot receive at the size of image
T30_ERR_TX_BADDCS = 14
Unexpected message received
T30_ERR_TX_BADPG = 15
Received bad response to DCS or training
T30_ERR_TX_ECMPHD = 16
Received a DCN from remote after sending a page
T30_ERR_TX_GOTDCN = 17
Invalid ECM response received from receiver
T30_ERR_TX_INVALRSP = 18
Received a DCN while waiting for a DIS
T30_ERR_TX_NODIS = 19
Invalid response after sending a page
T30_ERR_TX_PHBDEAD = 20
Received other than DIS while waiting for DIS
T30_ERR_TX_PHDDEAD = 21
Received no response to DCS, training or TCF
T30_ERR_TX_T5EXP = 22
No response after sending a page
T30_ERR_RX_ECMPHD = 23
Timed out waiting for receiver ready (ECM mode)
T30_ERR_RX_GOTDCS = 24
Invalid ECM response received from transmitter
T30_ERR_RX_INVALCMD = 25
DCS received while waiting for DTC
T30_ERR_RX_NOCARRIER = 26
Unexpected command after page received
T30_ERR_RX_NOEOL = 27
Carrier lost during fax receive
T30_ERR_RX_NOFAX = 28
Timed out while waiting for EOL (end of line)
T30_ERR_RX_T2EXPDCN = 29
Timed out while waiting for first line
T30_ERR_RX_T2EXPD = 30
Timer T2 expired while waiting for DCN
T30_ERR_RX_T2EXPFAX = 31
Timer T2 expired while waiting for phase D
T30_ERR_RX_T2EXPMPS = 32
Timer T2 expired while waiting for fax page
T30_ERR_RX_T2EXPRR = 33
Timer T2 expired while waiting for next fax page
T30_ERR_RX_T2EXP = 34
Timer T2 expired while waiting for RR command
T30_ERR_RX_DCNWHY = 35
Timer T2 expired while waiting for NSS, DCS or MCF
T30_ERR_RX_DCNDATA = 36
Unexpected DCN while waiting for DCS or DIS
T30_ERR_RX_DCNFAX = 37
Unexpected DCN while waiting for image data
T30_ERR_RX_DCNPHD = 38
Unexpected DCN while waiting for EOM, EOP or MPS
T30_ERR_RX_DCNRRD = 39
Unexpected DCN after EOM or MPS sequence
T30_ERR_RX_DCNNORTN = 40
Unexpected DCN after RR/RNR sequence
T30_ERR_FILEERROR = 41
Unexpected DCN after requested retransmission
T30_ERR_NOPAGE = 42
TIFF/F file cannot be opened
T30_ERR_BADTIFF = 43
TIFF/F page not found
T30_ERR_BADPAGE = 44
TIFF/F format is not compatible
T30_ERR_BADTAG = 45
TIFF/F page number tag missing
T30_ERR_BADTIFFHDR = 46
Incorrect values for TIFF/F tags
T30_ERR_NOMEM = 47
Bad TIFF/F header - incorrect values in fields
T30_ERR_RETRYDCN = 48
Cannot allocate memory for more pages
T30_ERR_CALLDROPPED = 49
Disconnected after permitted retries
T30_ERR_NOPOLL = 50
The call dropped prematurely
T30_ERR_IDENT_UNACCEPTABLE = 51
Poll not accepted
T30_ERR_SUB_UNACCEPTABLE = 52
Far end’s ident is not acceptable
T30_ERR_SEP_UNACCEPTABLE = 53
Far end’s sub-address is not acceptable
T30_ERR_PSA_UNACCEPTABLE = 54
Far end’s selective polling address is not acceptable
T30_ERR_SID_UNACCEPTABLE = 55
Far end’s polled sub-address is not acceptable
T30_ERR_PWD_UNACCEPTABLE = 56
Far end’s sender identification is not acceptable
T30_ERR_TSA_UNACCEPTABLE = 57
Far end’s password is not acceptable
T30_ERR_IRA_UNACCEPTABLE = 58
Far end’s transmitting subscriber internet address is not acceptable
T30_ERR_CIA_UNACCEPTABLE = 59
Far end’s internet routing address is not acceptable
T30_ERR_ISP_UNACCEPTABLE = 60
Far end’s calling subscriber internet address is not acceptable
T30_ERR_CSA_UNACCEPTABLE = 61
Far end’s internet selective polling address is not acceptable