pub unsafe extern "C" fn async_tx_init(
s: *mut async_tx_state_t,
data_bits: c_int,
parity: c_int,
stop_bits: c_int,
use_v14: bool,
get_byte: span_get_byte_func_t,
user_data: *mut c_void,
) -> *mut async_tx_state_tExpand description
Initialise an asynchronous data transmit context. \brief Initialise an asynchronous data transmit context. \param s The transmitter context. \param data_bits The number of data bit. \param parity The type of parity. \param stop_bits The number of stop bits. \param use_v14 True if V.14 rate adaption processing should be used. \param get_byte The callback routine used to get the data to be transmitted. \param user_data An opaque pointer. \return A pointer to the initialised context, or NULL if there was a problem.