pub unsafe extern "C" fn bitstream_flush(
s: *mut bitstream_state_t,
c: *mut *mut u8,
)Expand description
\brief Flush any residual bits to the output buffer. \param s A pointer to the bitstream context. \param c A pointer to the bitstream output buffer.