pub unsafe extern "C" fn bitstream_get(
s: *mut bitstream_state_t,
c: *mut *const u8,
bits: c_int,
) -> u32Expand description
\brief Get a chunk of bits from the input buffer. \param s A pointer to the bitstream context. \param c A pointer to the bitstream input buffer. \param bits The number of bits of value to be grabbed. 1 to 25 bits is valid. \return The value retrieved from the input buffer.