pub unsafe extern "C" fn queue_state_test_msg(
s: *mut queue_state_t,
) -> c_intExpand description
Test the length of the message at the head of a queue. \brief Test message length. \param s The queue context. \return The length of the next message, in byte. If there are no messages in the queue, -1 is returned.