pub unsafe extern "C" fn span_log_buf(
s: *mut logging_state_t,
level: c_int,
tag: *const c_char,
buf: *const u8,
len: c_int,
) -> c_intExpand description
Generate a log entry displaying the contents of a buffer. \brief Generate a log entry displaying the contents of a buffer \param s The logging context. \param level The severity level of the entry. \param tag A label for the log entry. \param buf The buffer to be dumped to the log. \param len The length of buf. \return 0 if no output generated, else 1.