pub unsafe extern "C" fn t85_encode_get(
s: *mut t85_encode_state_t,
buf: *mut u8,
max_len: usize,
) -> c_intExpand description
\brief Get the next chunk of the current document page. The document will be padded for the current minimum scan line time. \param s The T.85 context. \param buf The buffer into which the chunk is to written. \param max_len The maximum length of the chunk. \return The actual length of the chunk. If this is less than max_len it indicates that the end of the document has been reached.