pub unsafe extern "C" fn t85_encode_set_row_read_handler(
s: *mut t85_encode_state_t,
handler: t4_row_read_handler_t,
user_data: *mut c_void,
) -> c_intExpand description
\brief Set the row read handler for a T.85 encode context. \param s The T.85 context. \param handler A pointer to the handler routine. \param user_data An opaque pointer passed to the handler routine. \return 0 for success, otherwise -1.