pub type async_tx_state_t = async_tx_state_s;Expand description
Asynchronous data transmit descriptor. This defines the state of a single working instance of a byte to asynchronous serial converter, for use in FSK modems.
Aliased Type
pub struct async_tx_state_t { /* private fields */ }