pub type span_timestamp_t = u64;
\brief A timer variable large enough that when in microseconds it just won’t overflow. Most things in spandsp are timed by audio samples, but some things need access to global timers.